@@ -888,7 +888,7 @@ except for the \"pick\" command."
                     comment-start
                     (string-pad
                      (substitute-command-keys (format "\\[%s]" cmd)) 8)
-                    desc))))
+                    (replace-regexp-in-string "#" comment-start desc)))))
 
 (add-hook 'git-rebase-mode-hook #'git-rebase-mode-show-keybindings t)
 
