@@ -490,10 +490,7 @@ of a side, then keep that side without prompting."
     (pcase (list (magit-diff-type) (magit-diff-scope))
       (`(committed   ,_) (user-error "Cannot discard committed changes"))
       (`(undefined   ,_) (user-error "Cannot discard this change"))
-      (`(untracked list) (magit-discard-files--delete
-                          (magit-with-toplevel
-                            (magit-untracked-files nil nil "--directory"))
-                          nil))
+      (`(untracked list) (magit-discard-untracked))
       (`(,_      region) (magit-discard-region s))
       (`(,_        hunk) (magit-discard-hunk   s))
       (`(,_       hunks) (magit-discard-hunks  s))
@@ -501,6 +498,12 @@ of a side, then keep that side without prompting."
       (`(,_       files) (magit-discard-files  s))
       (`(,_        list) (magit-discard-files  s)))))
 
+(defun magit-discard-untracked ()
+  (magit-discard-files--delete
+   (magit-with-toplevel (magit-list-untracked-files))
+   nil)
+  (magit-refresh))
+
 (defun magit-discard-region (section)
   (magit-confirm 'discard "Discard region")
   (magit-discard-apply section 'magit-apply-region))
